discard

Function discard 

pub fn discard(repo: &Path, rel_crate: &str) -> Result<()>
Revert the crate working tree to the last checkpoint by restoring it from the index (the last accepted state, or the baseline if nothing is accepted yet).